==> jc-1.4.0.tar.gz: javax/swing/JColorChooser__24DefaultOKCancelListener.h <==
// class javax.swing.JColorChooser$DefaultOKCancelListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1c0709727491f943 javax_swing_JColorChooser__24DefaultOKCancelListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_
#define _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JDialog$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object;

typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method$_init$d82c9cc0c8fe0dde(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_javax_swing_JDialog$object *);

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods	javax_swing_JColorChooser__24DefaultOKCancelListener;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs {
	struct _jc_javax_swing_JDialog$object	*dialog;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs {
    _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs	javax_swing_JColorChooser__24DefaultOKCancelListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs	javax_swing_JColorChooser__24DefaultOKCancelListener;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object {
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24DefaultOKCancelListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JColorChooser__24DefaultOKCancelListener.h <==
// class javax.swing.JColorChooser$DefaultOKCancelListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1c0709727491f943 javax_swing_JColorChooser__24DefaultOKCancelListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_
#define _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JDialog$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object;

typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method$_init$d82c9cc0c8fe0dde(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_javax_swing_JDialog$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vmethods	javax_swing_JColorChooser__24DefaultOKCancelListener;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs {
	struct _jc_javax_swing_JDialog$object	*dialog;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs {
    _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_refs	javax_swing_JColorChooser__24DefaultOKCancelListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$sub_nonrefs	javax_swing_JColorChooser__24DefaultOKCancelListener;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$object {
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24DefaultOKCancelListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$vtype _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24DefaultOKCancelListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24DefaultOKCancelListener$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24DefaultOKCancelListener_H_ */
